# frozen_string_literal: true

require_relative "opentelemetry/version"
require_relative "opentelemetry/configurator"
require_relative "opentelemetry/resource/detectors/aspecto"
require "opentelemetry/sdk"
require "opentelemetry/exporter/otlp"
require "opentelemetry/instrumentation/all"

module Aspecto
  # Aspecto Opentelemetry Distro
  module Opentelemetry
    module_function

    class Error < StandardError; end

    def configure
      configurator = Configurator.new
      yield configurator if block_given?

      OpenTelemetry::SDK.configure do |c|
        c.service_name = configurator.service_name
        c.resource = Aspecto::Opentelemetry::Resource::Detectors::Aspecto.detect
        c.use_all "OpenTelemetry::Instrumentation::ActionPack" => { enable_recognize_route: true }

        c.add_span_processor(
          OpenTelemetry::SDK::Trace::Export::BatchSpanProcessor.new(
            OpenTelemetry::Exporter::OTLP::Exporter.new(endpoint: "https://otelcol.aspecto.io/v1/trace", headers: {
                                                          "Authorization" => configurator.aspecto_auth
                                                        })
          )
        )
      end
    end
  end
end
